@@ -12,7 +12,10 @@ class addone(object):
     def addtest(self):
         print(self.number + 1)
         print('Random numpy integer: ' + str(np.random.randint(4)))
-        sample_df = pd.DataFrame(pd.read_csv('data/sample_data.csv'))
+        for root, dirs, files in os.walk("."):
+            for filename in files:
+                print(filename)
+        sample_df = pd.DataFrame(pd.read_csv('src/examplepackagenishka/data/sample_data.csv'))
         print(sample_df.to_markdown())
 
 def main():
